import { NativeModules, Platform, processColor } from "react-native";

const { NavigationBarColor } = NativeModules;

const changeNavigationBarColor = (
  color = "#000000",
  light = false,
  animated = true
) => {
  if (Platform.OS === "android") {
    const LightNav = light ? true : false;

    if (color === "transparent" || color === "translucent") {
      return NavigationBarColor.changeNavigationBarColor(0, LightNav, animated);
    }

    const processedColor = processColor(color);

    if (processedColor == null || processedColor === 0) {
      console.warn(
        "Invalid color provided to changeNavigationBarColor:",
        color
      );
      return Promise.reject(new Error("Invalid color value"));
    }

    return NavigationBarColor.changeNavigationBarColor(
      processedColor,
      LightNav,
      animated
    );
  }
  return Promise.resolve({ success: false });
};

const hideNavigationBar = () => {
  if (Platform.OS === "android") {
    return NavigationBarColor.hideNavigationBar();
  }
  return Promise.resolve(false);
};

const showNavigationBar = () => {
  if (Platform.OS === "android") {
    return NavigationBarColor.showNavigationBar();
  }
  return Promise.resolve(false);
};

export { changeNavigationBarColor, hideNavigationBar, showNavigationBar };
